==> bibletime-trinity-3.5.13.2.tar.xz: bibletime-trinity-3.5.13.2/bibletime/frontend/display/creaddisplay.h <==
/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2006 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/



#ifndef CREADDISPLAY_H
#define CREADDISPLAY_H

#include "cdisplay.h"
#include "backend/cswordbackend.h"

class TQPopupMenu;
class TQWidget;

/**The base class for all read-only widgets like KHTMLView.
  *@author The BibleTime team
  */

class CReadDisplay :  public CDisplay {
public:
	/**
	* Returns true if the display has an active anchor.
	*/
	const bool hasActiveAnchor();
	/**
	* Returns the current active anchor.
	*/
	const TQString& activeAnchor();
	/**
	* Moves the widget to the given anchor.
	*/
	virtual void moveToAnchor( const TQString& ) = 0;
	virtual void print(const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions);

	void setMouseTracking(const bool trackingEnabled) {
		m_useMouseTracking = trackingEnabled;
	};
	const bool getMouseTracking() const {
		return m_useMouseTracking;
	};

protected: // Protected methods
	friend class CDisplay;
	friend class CHTMLReadDisplay;
	friend class CHTMLReadDisplayView;

	CReadDisplay( CReadWindow* readWindow );
	~CReadDisplay();

	/**
	* Sets the current anchor to the parameter.
	*/
	void setActiveAnchor( const TQString& );

private: // Public attributes
	/**
	* The member which hols the current anchor.
	*/

	TQString m_activeAnchor;

	bool m_useMouseTracking;
};

#endif

==> bibletime-trinity_14.2.0~pre46.orig.tar.xz: bibletime-trinity-14.2.0~pre46+67b13117/bibletime/frontend/display/creaddisplay.h <==
/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2006 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/



#ifndef CREADDISPLAY_H
#define CREADDISPLAY_H

#include "cdisplay.h"
#include "backend/cswordbackend.h"

class TQPopupMenu;
class TQWidget;

/**The base class for all read-only widgets like TDEHTMLView.
  *@author The BibleTime team
  */

class CReadDisplay :  public CDisplay {
public:
	/**
	* Returns true if the display has an active anchor.
	*/
	const bool hasActiveAnchor();
	/**
	* Returns the current active anchor.
	*/
	const TQString& activeAnchor();
	/**
	* Moves the widget to the given anchor.
	*/
	virtual void moveToAnchor( const TQString& ) = 0;
	virtual void print(const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions);

	void setMouseTracking(const bool trackingEnabled) {
		m_useMouseTracking = trackingEnabled;
	};
	const bool getMouseTracking() const {
		return m_useMouseTracking;
	};

protected: // Protected methods
	friend class CDisplay;
	friend class CHTMLReadDisplay;
	friend class CHTMLReadDisplayView;

	CReadDisplay( CReadWindow* readWindow );
	~CReadDisplay();

	/**
	* Sets the current anchor to the parameter.
	*/
	void setActiveAnchor( const TQString& );

private: // Public attributes
	/**
	* The member which hols the current anchor.
	*/

	TQString m_activeAnchor;

	bool m_useMouseTracking;
};

#endif
